@@ -3,8 +3,8 @@
 #' @title Average pairwise cross-sectional correlations
 #' @description Computes average pairwise cross-sectional correlations of the data and the country models' residuals.
 #' @details If used for analyzing the country models' residuals, \code{avg.pair.cc} computes for each country and a given variable, the average cross-sectional correlation (either for the data or for the residuals). In theory, including foreign variables should soak up cross-sectional residual dependence and  correlation of the residuals should be small. Otherwise dynamic analysis, especially using GIRFs, might lead to invalid results. See Dees et al. (2007) for more details.
-#' @usage avg.pair.cc(obj, digits=3)
-#' @param obj Either an object of class \code{bgvar} or residuals of class \code{bgvar.res}.
+#' @usage avg.pair.cc(object, digits=3)
+#' @param object Either an object of class \code{bgvar} or residuals of class \code{bgvar.res}.
 #' @param digits Number of digits that should be used to print output to the console.
 #' @return Returns a list with the following elements
 #' \item{\code{data.cor}}{ is a matrix containing in the rows the cross-sections and in the columns the cross-sectional pairwise correlations of the data per variable.}
@@ -24,24 +24,24 @@
 #' library(BGVAR)
 #' data(eerData)
 #' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=1,SV=TRUE,
-#'                   saves=100,burns=100,prior="MN")
+#'                   draws=100,burnin=100,prior="MN")
 #' avg.pair.cc(model.mn)
 #' 
 #' res <- residuals(model.mn)
 #' avg.pair.cc(res)
 #' }
 #' @importFrom stats cor
-avg.pair.cc=function(obj, digits=3){
-  if(class(obj)=="bgvar"){
-    plag <- obj$args$plag
-    dat  <- obj$xglobal[-c(1:plag),]
-    res  <- do.call("cbind",obj$cc.results$res)
+avg.pair.cc=function(object, digits=3){
+  if(class(object)=="bgvar"){
+    plag <- object$args$plag
+    dat  <- object$xglobal[-c(1:plag),]
+    res  <- do.call("cbind",object$cc.results$res)
     res  <- res[,colnames(dat)] 
   }
-  if(class(obj)=="bgvar.resid"){
-    dat    <- obj$Data
-    res    <- apply(obj$country,c(2,3),mean)  
-    res.g  <- apply(obj$global,c(2,3),mean) 
+  if(class(object)=="bgvar.resid"){
+    dat    <- object$Data
+    res    <- apply(object$country,c(2,3),mean)  
+    res.g  <- apply(object$global,c(2,3),mean) 
   }
   bigT     <- nrow(res)
   varNames <- colnames(dat)
@@ -60,7 +60,7 @@ avg.pair.cc=function(obj, digits=3){
   rownames(datL)<-rownames(resL)<-rownames(resL.g)<-cN
   colnames(datL)<-colnames(resL)<-colnames(resL.g)<-names(idx)
   
-  if(class(obj)=="bgvar"){
+  if(class(object)=="bgvar"){
     for(i in 1:length(idx)){
       aux.dat <- cor(dat[,idx[[i]]])
       aux.res <- cor(res[,idx[[i]]])
@@ -72,7 +72,7 @@ avg.pair.cc=function(obj, digits=3){
       resL[ii,i]<-aux.res
     }
   }
-  if(class(obj)=="bgvar.resid"){  # include analysis based on residuals of the global model as well
+  if(class(object)=="bgvar.resid"){  # include analysis based on residuals of the global model as well
     for(i in 1:length(idx)){
       aux.dat <- cor(dat[,idx[[i]]])
       aux.res <- cor(res[,idx[[i]]])
@@ -117,8 +117,11 @@ avg.pair.cc=function(obj, digits=3){
     res.resG[4,i]<-paste(length(which(aux3>0.5&aux3<=1))," (",round((length(which(aux3>0.5&aux3<=1))/K3)*100,2),"%)",sep="")
     
   }
-  rownames(dat.res)<-rownames(res.res)<-rownames(res.resG)<-c("<0.1","0.1-0.2","0.2-0.5",">0.5")
-  colnames(dat.res)<-colnames(res.res)<-colnames(res.resG)<-colnames(datL)
+  colnames(dat.res) <- colnames(res.res) <- colnames(res.resG) <- colnames(datL)
+  rownames(dat.res) <- rownames(res.res) <- rownames(res.resG) <- c("<0.1","0.1-0.2","0.2-0.5",">0.5")
+  #dat.res  <- rbind(c("",colnames(datL)),cbind(c("<0.1","0.1-0.2","0.2-0.5",">0.5"),dat.res))
+  #res.res  <- rbind(c("",colnames(datL)),cbind(c("<0.1","0.1-0.2","0.2-0.5",">0.5"),res.res))
+  #res.resG <- rbind(c("",colnames(datL)),cbind(c("<0.1","0.1-0.2","0.2-0.5",">0.5"),res.resG))
   
   avg.cc<-list(data.cor=datL,resid.cor=resL,resid.corG=resL.g,dat.res=dat.res,res.res=res.res,res.resG=res.resG)
   return(avg.cc)
@@ -143,7 +146,7 @@ avg.pair.cc=function(obj, digits=3){
 #' \donttest{
 #' library(BGVAR)
 #' data(eerData)
-#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=1,saves=200,burns=200,prior="MN")
+#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=1,draws=200,burnin=200,prior="MN")
 #' geweke <- conv.diag(model.mn)
 #' }
 #' @references 
@@ -175,150 +178,12 @@ conv.diag<-function(object, crit.val=1.96){
   return(return)
 }
 
-#' @name print.bgvar.CD
-#' @title Print convergence diagnostics
-#' @param x object of class \code{bgvar.CD}.
-#' @param ... additional arguments.
-#' @return No return value.
+#' @method print bgvar.CD
 #' @export
 print.bgvar.CD <- function(x, ...){
-  if(!inherits(x, "bgvar.CD")) {stop("Please provide a 'bgvar.CD' object.")}
   cat(x$perc)
 }
 
-#' @name BIC.bgvar
-#' @title Bayesian Information Criterion
-#' @description Computes the Bayesian information criterion for an object \code{bgvar}.
-#' @param object an object of class \code{bgvar}.
-#' @param ... additional arguments.
-#' @return Returns a numeric value with the corresponding BIC.
-#' @author Maximilian Boeck
-#' @export
-#' @examples 
-#' \dontshow{
-#' library(BGVAR)
-#' data(eerData)
-#' cN<-c("EA","US","UK")
-#' eerData<-eerData[cN]
-#' W.trade0012<-apply(W.trade0012[cN,cN],2,function(x)x/rowSums(W.trade0012[cN,cN]))
-#' model.ssvs<-bgvar(Data=eerData,W=W.trade0012,plag=1,saves=100,burns=100,prior="SSVS")
-#' BIC(model.ssvs)
-#' }
-#' \donttest{
-#' library(BGVAR)
-#' data(eerData)
-#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=2,saves=100,burns=100,prior="MN")
-#' BIC(model.mn)
-#' }
-#' @references 
-#' Schwartz, G. E. (1978) \emph{Estimating the dimension of a model.} Annals of Statistics, Vol. 6(2), pp. 461-464.
-#' @importFrom stats quantile BIC
-BIC.bgvar <- function(object, ...){
-  if(!inherits(object, "bgvar")) {stop("Please provide a `bgvar` object.")}
-  if(!is.null(object$args$logLik)){
-    globalLik <- object$args$logLik
-  }else{
-    xglobal   <- object$xglobal
-    plag      <- object$args$plag
-    trend     <- object$args$trend
-    bigT      <- nrow(xglobal)
-    bigK      <- ncol(xglobal)
-    thinsaves <- object$args$thinsaves
-    X_large   <- cbind(.mlag(xglobal,plag),1)
-    if(trend) X_large <- cbind(X_large,seq(1:bigT))
-    Y_large   <- xglobal[(plag+1):bigT,,drop=FALSE]
-    X_large   <- X_large[(plag+1):bigT,,drop=FALSE]
-    A_large   <- object$stacked.results$A_large
-    S_large   <- object$stacked.results$S_large
-    Ginv_large<- object$stacked.results$Ginv_large
-    globalLik <- c(globalLik(Y_in=Y_large,X_in=X_large,A_in=A_large,S_in=S_large,Ginv_in=Ginv_large,thinsaves=thinsaves)$globalLik)
-    globalLik <- median(globalLik)
-  }
-  if(!is.null(object$args$BIC)){
-    out <- object$args$BIC
-  }else{
-    M <- sum(sapply(object$cc.results$coeffs,length))
-    S <- sum(sapply(object$args$Data,function(x) ncol(x)^2))
-    
-    out <- (M+S)*log(bigT) - 2*globalLik
-  }
-  if(is.null(object$args$logLik)){
-    eval.parent(substitute(object$args$logLik<-globalLik))
-  }
-  if(is.null(object$args$BIC)){
-    eval.parent(substitute(object$args$BIC<-out))
-  }
-  return(out)
-}
-
-#' @name AIC.bgvar
-#' @title Akaike Information Criterion
-#' @description Computes the Akaike information criterion for an object \code{bgvar}.
-#' @param object an object of class \code{bgvar}.
-#' @param ... additional arguments.
-#' @param k the penalty per parameter to be used. Default is set to \code{k=2}.
-#' @return Returns a numeric value with the corresponding AIC.
-#' @author Maximilian Boeck
-#' @export
-#' @examples
-#' \dontshow{
-#' library(BGVAR)
-#' data(eerData)
-#' cN<-c("EA","US","UK")
-#' eerData<-eerData[cN]
-#' W.trade0012<-apply(W.trade0012[cN,cN],2,function(x)x/rowSums(W.trade0012[cN,cN]))
-#' model.ssvs <- bgvar(Data=eerData,W=W.trade0012,plag=1,saves=100,burns=100,prior="SSVS")
-#' AIC(model.ssvs)
-#' }
-#' \donttest{
-#' library(BGVAR)
-#' data(eerData)
-#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=2,saves=100,burns=100,prior="MN")
-#' AIC(model.mn)
-#' }
-#' @references 
-#' Akaike, H. (1973) Information theory and an extension of the maximum likelihood principle. In: B. N. Petro and F. Csaki (eds.), 2nd International Symposium on Information Theory, pp. 267-281.
-#' 
-#' Akaike, H. (1974) A new look at the statistical model identification. \emph{IEEE Transactions on Automatic Control AC-19}, pp. 716-723.
-#' @importFrom stats quantile AIC
-AIC.bgvar <- function(object, ..., k = 2){
-  if(!inherits(object, "bgvar")) {stop("Please provide a `bgvar` object.")}
-  if(!is.null(object$args$logLik)){
-    globalLik <- object$args$logLik
-  }else{
-    xglobal   <- object$xglobal
-    plag      <- object$args$plag
-    trend     <- object$args$trend
-    bigT      <- nrow(xglobal)
-    bigK      <- ncol(xglobal)
-    thinsaves <- object$args$thinsaves
-    X_large   <- cbind(.mlag(xglobal,plag),1)
-    if(trend) X_large <- cbind(X_large,seq(1:bigT))
-    Y_large   <- xglobal[(plag+1):bigT,,drop=FALSE]
-    X_large   <- X_large[(plag+1):bigT,,drop=FALSE]
-    A_large   <- object$stacked.results$A_large
-    S_large   <- object$stacked.results$S_large
-    Ginv_large<- object$stacked.results$Ginv_large
-    globalLik <- c(globalLik(Y_in=Y_large,X_in=X_large,A_in=A_large,S_in=S_large,Ginv_in=Ginv_large,thinsaves=thinsaves)$globalLik)
-    globalLik <- median(globalLik)
-  }
-  if(!is.null(object$args$AIC)){
-    out <- object$args$AIC
-  }else{
-    M <- sum(sapply(object$cc.results$coeffs,length))
-    S <- sum(sapply(object$args$Data,function(x) ncol(x)^2))
-    
-    out <- 2*(M+S) - 2*globalLik
-  }
-  if(is.null(object$args$logLik)){
-    eval.parent(substitute(object$args$logLik<-globalLik))
-  }
-  if(is.null(object$args$AIC)){
-    eval.parent(substitute(object$args$AIC<-out))
-  }
-  return(out)
-}
-
 #' @name DIC
 #' @title Deviance Information Criterion
 #' @description Computes the Deviance information criterion for an object \code{bgvar}.
@@ -334,14 +199,14 @@ AIC.bgvar <- function(object, ..., k = 2){
 #' cN<-c("EA","US","UK")
 #' eerData<-eerData[cN]
 #' W.trade0012<-apply(W.trade0012[cN,cN],2,function(x)x/rowSums(W.trade0012[cN,cN]))
-#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=2,saves=100,burns=100,prior="MN")
+#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=2,draws=100,burnin=100,prior="MN")
 #' DIC(model.mn)
 #' }
 #' \donttest{
 #' set.seed(1)
 #' library(BGVAR)
 #' data(eerData)
-#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=1,saves=100,burns=100,prior="MN")
+#' model.mn <- bgvar(Data=eerData,W=W.trade0012,plag=1,draws=100,burnin=100,prior="MN")
 #' DIC(model.mn)
 #' }
 #' @references 
@@ -356,7 +221,7 @@ DIC <- function(object, ...){
     trend     <- object$args$trend
     bigT      <- nrow(xglobal)
     bigK      <- ncol(xglobal)
-    thinsaves <- object$args$thinsaves
+    thindraws <- object$args$thindraws
     X_large   <- cbind(.mlag(xglobal,plag),1)
     if(trend) X_large <- cbind(X_large,seq(1:bigT))
     Y_large   <- xglobal[(plag+1):bigT,,drop=FALSE]
@@ -364,7 +229,7 @@ DIC <- function(object, ...){
     A_large   <- object$stacked.results$A_large
     S_large   <- object$stacked.results$S_large
     Ginv_large<- object$stacked.results$Ginv_large
-    globalLik <- c(globalLik(Y_in=Y_large,X_in=X_large,A_in=A_large,S_in=S_large,Ginv_in=Ginv_large,thinsaves=thinsaves)$globalLik)
+    globalLik <- c(globalLik(Y_in=Y_large,X_in=X_large,A_in=A_large,S_in=S_large,Ginv_in=Ginv_large,thindraws=thindraws)$globalLik)
     A_mean     <- apply(A_large,c(2,3),mean)
     S_mean     <- apply(S_large,c(2,3),mean)
     Ginv_mean  <- apply(Ginv_large,c(2,3),mean)
@@ -402,12 +267,11 @@ DIC <- function(object, ...){
 #' Godfrey, L.G. (1978b) \emph{Testing for Higher Order Serial Correlation in Regression Equations When the Regressors Include Lagged Dependent Variables.} Econometrica, 46, pp. 1303-1310.
 #' Smith, L. V. and A. Galesi (2014) \emph{GVAR Toolbox 2.0 User Guide}, available at \url{https://sites.google.com/site/gvarmodelling/gvar-toolbox}.
 #' 
-#' @seealso \code{\link{print.bgvar}}
 #' @examples
 #' \donttest{
 #' library(BGVAR)
 #' data(eerData)
-#' model.mn <- bgvar(Data=eerData,W=W.trade0012,saves=100,burns=100,plag=1,prior="MN")
+#' model.mn <- bgvar(Data=eerData,W=W.trade0012,draws=100,burnin=100,plag=1,prior="MN")
 #' residual.corr.test(model.mn)
 #' }
 #' @importFrom stats pf qf
