@@ -329,8 +329,14 @@ cond.predict <- function(constr, bgvar.obj, pred.obj, constr_sd=NULL, verbose=TR
   return(out)
 }
 
-#' @name lps.bgvar.pred
+#' @export
+"lps" <- function(object){
+  UseMethod("lps", object)
+}
+
+#' @name lps
 #' @title Compute log-predictive scores
+#' @method lps bgvar.pred
 #' @description  Computes and prints log-predictive score of an object of class \code{bgvar.predict}.
 #' @param object an object of class \code{bgvar.predict}.
 #' @param ... additional arguments.
@@ -358,7 +364,7 @@ cond.predict <- function(constr, bgvar.obj, pred.obj, constr_sd=NULL, verbose=TR
 #' @author Maximilian Boeck, Martin Feldkircher
 #' @importFrom stats dnorm
 #' @export
-lps <- function(object, ...){
+lps.bgvar.pred <- function(object, ...){
   hold.out <- object$hold.out
   h        <- nrow(hold.out)
   K        <- ncol(hold.out)
@@ -375,8 +381,14 @@ lps <- function(object, ...){
   return(out)
 }
 
-#' @name rmse.bgvar.predict
+#' @export
+"rmse" <- function(object){
+  UseMethod("rmse", object)
+}
+
+#' @name rmse
 #' @title Compute root mean squared errors
+#' @method rmse bgvar.pred
 #' @description  Computes and prints root mean squared errors (RMSEs) of an object of class \code{bgvar.predict}.
 #' @param object an object of class \code{bgvar.predict}.
 #' @param ... additional arguments.
@@ -405,7 +417,7 @@ lps <- function(object, ...){
 #' @importFrom knitr kable
 #' @importFrom stats dnorm
 #' @export
-rmse <- function(object, ...){
+rmse.bgvar.pred <- function(object, ...){
   hold.out <- object$hold.out
   h        <- nrow(hold.out)
   K        <- ncol(hold.out)
